==> tika-2.4.1-src.zip: tika-2.4.1/tika-eval/tika-eval-app/src/main/java/org/apache/tika/eval/app/tools/BatchTopCommonTokenCounter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.eval.app.tools;

import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import java.util.Map;

import org.apache.tika.utils.ProcessUtils;

/**
 * Utility class that runs TopCommonTokenCounter against a directory
 * of table files (named {lang}_table.gz or leipzip-like afr_...-sentences.txt)
 * and outputs common tokens files for each input table file in the output directory.
 */
public class BatchTopCommonTokenCounter {

    public static void main(String[] args) throws Exception {

        Path commonTokensDir = Paths.get(args[0]);
        Path tableFileDir = Paths.get(args[1]);
        Map<String, List<Path>> langFiles = LeipzigHelper.getFiles(tableFileDir);

        for (Map.Entry<String, List<Path>> e : langFiles.entrySet()) {

            String[] cmd = new String[e.getValue().size() + 1];
            Path commonTokensFile = commonTokensDir.resolve(e.getKey());
            cmd[0] = ProcessUtils.escapeCommandLine(commonTokensFile.toAbsolutePath().toString());
            for (int i = 0; i < e.getValue().size(); i++) {
                cmd[i + 1] = ProcessUtils
                        .escapeCommandLine(e.getValue().get(i).toAbsolutePath().toString());
            }
            TopCommonTokenCounter.main(cmd);
        }
    }
}

==> tika-3.2.3-src.zip: tika-3.2.3/tika-eval/tika-eval-app/src/main/java/org/apache/tika/eval/app/tools/BatchTopCommonTokenCounter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.eval.app.tools;

import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import java.util.Map;

import org.apache.tika.utils.ProcessUtils;

/**
 * Utility class that runs TopCommonTokenCounter against a directory
 * of table files (named {lang}_table.gz or leipzip-like afr_...-sentences.txt)
 * and outputs common tokens files for each input table file in the output directory.
 */
public class BatchTopCommonTokenCounter {

    public static void main(String[] args) throws Exception {

        Path commonTokensDir = Paths.get(args[0]);
        Path tableFileDir = Paths.get(args[1]);
        Map<String, List<Path>> langFiles = LeipzigHelper.getFiles(tableFileDir);

        for (Map.Entry<String, List<Path>> e : langFiles.entrySet()) {

            String[] cmd = new String[e
                    .getValue()
                    .size() + 1];
            Path commonTokensFile = commonTokensDir.resolve(e.getKey());
            cmd[0] = ProcessUtils.escapeCommandLine(commonTokensFile
                    .toAbsolutePath()
                    .toString());
            for (int i = 0; i < e
                    .getValue()
                    .size(); i++) {
                cmd[i + 1] = ProcessUtils.escapeCommandLine(e
                        .getValue()
                        .get(i)
                        .toAbsolutePath()
                        .toString());
            }
            TopCommonTokenCounter.main(cmd);
        }
    }
}
